#
# spec file for package python-ipydatawidgets
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define mainver 4.3.5
%define labver  7.1.2
%define jupver  5.5.2
Name:           python-ipydatawidgets
Version:        %{mainver}
Release:        12.1
Summary:        Jupyter widgets to help facilitate reuse of large datasets
License:        BSD-3-Clause
Group:          Development/Languages/Python
URL:            https://github.com/vidartf/ipydatawidgets
Source0:        https://files.pythonhosted.org/packages/py2.py3/i/ipydatawidgets/ipydatawidgets-%{mainver}-py2.py3-none-any.whl
BuildRequires:  %{python_module base >= 3.7}
BuildRequires:  %{python_module ipywidgets >= 7.0.0}
BuildRequires:  %{python_module numpy < 2}
BuildRequires:  %{python_module pip}
BuildRequires:  %{python_module traittypes >= 0.2.0}
BuildRequires:  fdupes
BuildRequires:  jupyter-rpm-macros
BuildRequires:  python-rpm-macros
# SECTION test requirements
BuildRequires:  %{python_module nbval}
BuildRequires:  %{python_module pytest}
# /SECTION
Requires:       jupyter-ipydatawidgets = %{jupver}
Requires:       python-ipywidgets >= 7.0.0
# https://github.com/vidartf/ipydatawidgets/issues/62
Requires:       python-numpy < 2
Requires:       python-traittypes >= 0.2.0
Provides:       python-jupyter_ipydatawidgets = %{mainver}
Obsoletes:      python-jupyter_ipydatawidgets < %{mainver}
BuildArch:      noarch
%python_subpackages

%description
IPydatawidgets is a set of widgets to help facilitate reuse of large
datasets across different widgets, and different packages.

This package provides the python interface.

%package     -n jupyter-ipydatawidgets
Version:        %{jupver}
Release:        12.1
Summary:        Jupyter widgets to help facilitate reuse of large datasets
Group:          Development/Languages/Python
Requires:       (jupyter-notebook < 7 or jupyter-nbclassic)
Provides:       jupyter-datawidgets = %{jupver}
Requires:       python3dist(ipydatawidgets) = %{mainver}
Suggests:       python3-ipydatawidgets

%description -n jupyter-ipydatawidgets
IPydatawidgets is a set of widgets to help facilitate reuse of large
datasets across different widgets, and different packages.

This package provides the jupyter notebook extension.

%package     -n jupyter-ipydatawidgets-jupyterlab
Version:        %{labver}
Release:        12.1
Summary:        JupyterLab Widgets to help facilitate reuse of large datasets
Group:          Development/Languages/Python
Requires:       jupyter-jupyterlab
Requires:       python3dist(ipydatawidgets) = %{mainver}
Suggests:       python3-ipydatawidgets
Provides:       jupyter-datawidgets-jupyterlab = %{labver}
Provides:       jupyter_ipydatawidgets_jupyterlab = %{labver}
Obsoletes:      jupyter_ipydatawidgets_jupyterlab < %{labver}

%description -n jupyter-ipydatawidgets-jupyterlab
IPydatawidgets is a set of widgets to help facilitate reuse of large
datasets across different widgets, and different packages.

This package provides the JupyterLab extension.

%prep
%setup -q -T -c

%build
# Not needed: we must use the prebundled jsfiles from the published wheel

%install
%pyproject_install %{SOURCE0}
%{jupyter_move_config}
%{python_expand pushd %{buildroot}%{$python_sitelib}
find ipydatawidgets/ -type f -name "*.py" -exec sed -i 's/\r$//' {} +
find ipydatawidgets/ -type f -name "*.py" -exec sed -i -e '/^#!\//, 1d' {} +
%{$python_compile}
%fdupes %{buildroot}%{$python_sitelib}
popd
}
%fdupes %{buildroot}%{_jupyter_prefix}
cp %{buildroot}%{python3_sitelib}/ipydatawidgets-%{mainver}.dist-info/LICENSE.txt .

%check
export LANG=en_US.UTF-8
%pytest --pyargs ipydatawidgets

%files %{python_files}
%license LICENSE.txt
%{python_sitelib}/ipydatawidgets-%{mainver}*.dist-info/
%{python_sitelib}/ipydatawidgets/

%files -n jupyter-ipydatawidgets
%license LICENSE.txt
%{_jupyter_nbextension_dir}/jupyter-datawidgets/
%_jupyter_config %{_jupyter_nb_notebook_confdir}/jupyter-datawidgets.json

%files -n jupyter-ipydatawidgets-jupyterlab
%license LICENSE.txt
%{_jupyter_labextensions_dir}/jupyterlab-datawidgets-%{labver}.tgz
%dir %{_jupyter_prefix}/labextensions
%{_jupyter_prefix}/labextensions/jupyterlab-datawidgets

%changelog
* Sun May  5 2024 Ben Greiner <code@bnavigator.de>
- Pin to numpy < 2:  gh#vidartf/ipydatawidgets#62
* Tue Mar  5 2024 Ben Greiner <code@bnavigator.de>
- Skip python39: no longer supported since ipython 8.19 (through
  ipywidgets)
* Sat Aug 26 2023 Ben Greiner <code@bnavigator.de>
- Update to 4.3.5
  * no upstream release notes
  * merged patch below
- Drop ipydatawidgets-pr56-traitlets-fix.patch
- Fix jupyter package chain for multiflavor
* Sun Feb 19 2023 Ben Greiner <code@bnavigator.de>
- Add ipydatawidgets-pr56-traitlets-fix.patch
  * gh#ipydatawidgets/pull#56
  * Fixes gh#ipydatawidgets/pull#52
* Sun Aug 28 2022 Ben Greiner <code@bnavigator.de>
- Update to 4.3.2
  * jupyter-datawidgets 5.5.2
  * jupyerlab-datawidgets 7.1.2
  * no release notes
  * Drop Python2 and Python 3.6 support
- fixes failures with recent ipywidgets 8.0.1
* Sun Aug 21 2022 Ben Greiner <code@bnavigator.de>
- Update to 4.3.1.post1
  * jupyter-datawidgets 5.5.1
  * jupyerlab-datawidgets 7.1.1.
  * no release notes
  * ipywidgets 8 support
  * typing changes
* Sat Apr 10 2021 Ben Greiner <code@bnavigator.de>
- fix error in the subpackage requirements/version labyrinth
* Thu Mar 11 2021 Ben Greiner <code@bnavigator.de>
- Update to 4.2.0
  * jupyter-datawidgets 5.4.0
  * jupyerlab-datawidgets 7.0.0
  * no release notes
  * jupyterlab 2.0 and 3.0 support
  * updated numpy api support
- Skip python36 build: With NumPy 1.20, python36-numpy is no
  longer available in Tumbleweed (NEP 29)
* Tue Dec 15 2020 Benjamin Greiner <code@bnavigator.de>
- remove post and preun requires. There are no scriptlets for these
  anymore and the ifpython3 condition will be broken by
  gh#openSUSE#python-rpm-macros#66
* Tue Dec 31 2019 Bernhard Wiedemann <bwiedemann@suse.com>
- Do not rewrite source archive during build
- Use pyproject_install macro (boo#1094323)
* Wed Nov 13 2019 Todd R <toddrme2178@gmail.com>
- Fix dependencies
* Sun Aug 11 2019 Todd R <toddrme2178@gmail.com>
- Update to 4.0.1
  * Ensure python tests pass
  * Update clean/publish scripts
  * Add missing dev deps
  * Update tests to lab 1.0
* Mon Aug  5 2019 Todd R <toddrme2178@gmail.com>
- Fix dependencies
* Thu Apr 25 2019 Todd R <toddrme2178@gmail.com>
- Rename to to match python package naming guidelines.
- Split jupyter components into own subpackage.
* Fri Jan  4 2019 Todd R <toddrme2178@gmail.com>
- Update to 4.0.0
  * Update frontend dep
  * Update publish script
  * Cleanup tsconfig
  * Add NDArraySource
  * Refactor NDArrayWidget on top of base class
  * Add DataImage widget
  * Also export base model in JS
  * Remove scaled datawidget
* Fri Sep 28 2018 Todd R <toddrme2178@gmail.com>
- Update to 3.2.0
  * Refactor scaled widget, add tests
  * Scales external cleanup
  * Fix nbval test
  * Make ipyscales optional
  * Test deprecated method to get 100%% coverage
  * Add py tests for compression, and fix bugs
  * Add more serializer types
  * Add docstrings for ndarray serializers
  * Add support for compression
* Thu Sep 20 2018 Todd R <toddrme2178@gmail.com>
- jupyterlab no longer supports python2 so don't BuildRequires
  python2 version.
* Fri Aug  3 2018 toddrme2178@gmail.com
- Update to 3.1.0
  * Regen package lock
  * Fix test for python 3.4
  * Rebase onto trait_types 0.2.0
* Fri Apr 20 2018 toddrme2178@gmail.com
- Initial version
